<?php
/**
 * Subscription settings
 *
 * @package     RCP\ActiveCampaign\Admin\Subscription\MetaBoxes
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 * Add per-level setting fields
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_activecampaign_add_subscription_settings() {
	?>
		<tr class="form-field">
			<th scope="row" valign="top">
				<label for="rcp-activecampaign-list"><?php _e( 'ActiveCampaign List', 'rcp-activecampaign' ); ?></label>
			</th>
			<td>
				<?php
				$lists = rcp_activecampaign()->api_helper->get_lists();

				if( isset( $_GET['edit_subscription'] ) ) {
					$subscription_lists = get_option( 'rcp_activecampaign_subscription_lists' );

					if( is_array( $subscription_lists ) && array_key_exists( $_GET['edit_subscription'], $subscription_lists ) ) {
						$saved_list = $subscription_lists[$_GET['edit_subscription']];
					} else {
						$saved_list = false;
					}
				} else {
					$saved_list = false;
				}

				if( $lists ) {
					?>
					<select name="activecampaign-list" id="rcp-activecampaign-list">
						<option value="inherit"<?php echo selected( $saved_list, 'inherit', false ); ?>><?php _e( 'Use System Default', 'rcp-activecampaign' ); ?></option>
						<?php
						foreach( $lists as $list_id => $list_name ) {
							echo '<option value="' . esc_attr( $list_id ) . '"' . selected( $saved_list, $list_id, false ) . '>' . esc_html( $list_name ) . '</option>';
						} ?>
					</select>
					<p class="description"><?php _e( 'The ActiveCampaign list to subscribe users to at this level.', 'rcp-activecampaign' ); ?></p>
					<?php
				} else {
					echo __( 'Enter valid API details to select a list.', 'rcp-activecampaign' );
				}
				?>
			</td>
		</tr>
	<?php
}
add_action( 'rcp_add_subscription_form', 'rcp_activecampaign_add_subscription_settings' );
add_action( 'rcp_edit_subscription_form', 'rcp_activecampaign_add_subscription_settings' );


/**
 * Store the ActiveCampaign list in subscription meta
 *
 * @since       1.0.0
 * @param       int $level_id The subscription ID
 * @param       array $args Arguements passed to the action
 */
function rcp_activecampaign_save_subscription( $level_id = 0, $args ) {
	if( ! empty( $_POST['activecampaign-list'] ) ) {
		$saved_lists = get_option( 'rcp_activecampaign_subscription_lists' );
		$saved_lists[$level_id] = $_POST['activecampaign-list'];

		update_option( 'rcp_activecampaign_subscription_lists', $saved_lists );
	}
}
add_action( 'rcp_add_subscription', 'rcp_activecampaign_save_subscription', 10, 2 );
add_action( 'rcp_edit_subscription_level', 'rcp_activecampaign_save_subscription', 10, 2 );