<?php
namespace RCP\Addon\DripContent\Settings;

defined( 'WPINC' ) or die;

/**
 * Displays the drip schedule form fields on the subscription level edit screen.
 */
function subscription_form_fields( $level ) {

	$db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( array( 'level_id' => $level->id ) );

	$schedules = $db->schedules_for_level();

	$schedules = ( ! empty( $schedules ) ) ? $schedules : array();

	foreach( $schedules as $key => $schedule ) {
		$schedules[$key]['taxonomy_type_display'] = 'taxonomy' === $schedules[$key]['type'] ? '' : ' style="display: none;"';
		$schedules[$key]['terms_display']         = 'taxonomy' === $schedules[$key]['type'] ? '' : ' style="display: none;"';
		$schedules[$key]['post_type_display']     = 'post' === $schedules[$key]['type'] ? '' : 'style="display: none;"';
		$schedules[$key]['posts_display']         = 'post' === $schedules[$key]['type'] ? '' : 'style="display: none;"';
	}
?>
	<style>
		.form-table .rcp-drip-schedule-type-table-header-type {
			width: 120px;
		}
		.rcp-drip-schedule-row td {
			padding-left: 0;
			padding-right: 0;
		}
		.rcp-drip-schedule-row td:nth-child(2) {
			width: 105px;
			padding-right: 10px;
		}
		.rcp-drip-type-control {
			min-width: 60%;
			max-width: 95%;
		}
		.rcp-drip-taxonomy-control,
		.rcp-drip-post-type-control,
		.rcp-drip-taxonomy-terms-control,
		.rcp-drip-post-type-matches-control {
			min-width: 95%;
			max-width: 95%;
		}
		.rcp-drip-schedule-remove {
			margin-top: 5px;
			text-decoration: none;
		}
		.form-table .rcp-drip-schedule-unit-table-header,
		.form-table .rcp-drip-schedule-period-table-header {
			width: 40px;
		}
	</style>

	<tr class="form-field" id="rcp-drip-schedule-wrapper">
		<th scope="row" valign="top">
			<label for="rcp-drip-type"><?php _e( 'Drip Schedule', 'rcp-drip-content' ); ?></label>
		</th>

		<td class="rcp-drip-schedule-table-wrapper">
			<table>
				<thead>
					<tr>
						<th scope="col" colspan="1" class="rcp-drip-schedule-type-table-header-type"><?php _e( 'Type', 'rcp-drip-content' ); ?></th>
						<th scope="col" colspan="2" class="rcp-drip-schedule-type-table-header-content"><?php _e( 'Content', 'rcp-drip-content' ); ?></th>
						<th scope="col" colspan="3" class="rcp-drip-schedule-unit-table-header-delay-access"><?php _e( 'Delay Access', 'rcp-drip-content' ); ?></th>
					</tr>
				</thead>
				<tbody>
					<?php
					if ( ! empty( $schedules ) ) :

						foreach( $schedules as $key => $schedule ) {
							do_action( 'rcp_render_drip_schedule_row', $key, $schedule );
						}
					else :
						do_action( 'rcp_render_drip_schedule_row', 0, array( 'taxonomy_type_display' => '', 'terms_display' => '' ) );

					endif;
					?>
				</tbody>
			</table>
			<input name="rcp-drip-add-row" type="button" class="rcp-drip-schedule-add button" value="<?php _e( 'Add a Schedule', 'rcp-drip-content' ); ?>" />
			<p class="description"><?php _e( 'The drip release schedule for this subscription level. Optional. <strong>Note:</strong> Defining a schedule here does not define the actual restrictions on the content or taxonomy. It only schedules the visibility of the restrictions you have defined on those items. You must define restrictions on those items to make the drip schedule work and to protect your content.', 'rcp-drip-content' ); ?></p>
		</td>
	</tr>
<?php

}
add_action( 'rcp_edit_subscription_form', '\RCP\Addon\DripContent\Settings\subscription_form_fields' );

/**
 * Displays the drip schedule form fields on the subscription level edit screen.
 */
function add_subscription_form_fields() {

	?>
	<style>
		.form-table .rcp-drip-schedule-type-table-header-type {
			width: 120px;
		}
		.rcp-drip-schedule-row td {
			padding-left: 0;
			padding-right: 0;
		}
		.rcp-drip-schedule-row td:nth-child(2) {
			width: 105px;
			padding-right: 10px;
		}
		.rcp-drip-type-control {
			min-width: 60%;
			max-width: 95%;
		}
		.rcp-drip-taxonomy-control,
		.rcp-drip-post-type-control,
		.rcp-drip-taxonomy-terms-control,
		.rcp-drip-post-type-matches-control {
			min-width: 95%;
			max-width: 95%;
		}
		.rcp-drip-schedule-remove {
			margin-top: 5px;
			text-decoration: none;
		}
		.form-table .rcp-drip-schedule-unit-table-header,
		.form-table .rcp-drip-schedule-period-table-header {
			width: 40px;
		}
	</style>

	<tr class="form-field" id="rcp-drip-schedule-wrapper">
		<th scope="row" valign="top">
			<label for="rcp-drip-type"><?php _e( 'Drip Schedule', 'rcp-drip-content' ); ?></label>
		</th>

		<td class="rcp-drip-schedule-table-wrapper">
			<table>
				<thead>
					<tr>
						<th scope="col" colspan="1" class="rcp-drip-schedule-type-table-header-type"><?php _e( 'Type', 'rcp-drip-content' ); ?></th>
						<th scope="col" colspan="2" class="rcp-drip-schedule-type-table-header-content"><?php _e( 'Content', 'rcp-drip-content' ); ?></th>
						<th scope="col" colspan="3" class="rcp-drip-schedule-unit-table-header-delay-access"><?php _e( 'Delay Access', 'rcp-drip-content' ); ?></th>
					</tr>
				</thead>
				<tbody>
					<?php do_action( 'rcp_render_drip_schedule_row', 0, array( 'taxonomy_type_display' => '', 'terms_display' => '' ) ); ?>
				</tbody>
			</table>
			<input name="rcp-drip-add-row" type="button" class="rcp-drip-schedule-add button" value="<?php _e( 'Add a Schedule', 'rcp-drip-content' ); ?>" />
			<p class="description"><?php _e( 'The drip release schedule for this subscription level. Optional. <strong>Note:</strong> Defining a schedule here does not define the actual restrictions on the content or taxonomy. It only schedules the visibility of the restrictions you have defined on those items. You must define restrictions on those items to make the drip schedule work and to protect your content.', 'rcp-drip-content' ); ?></p>
		</td>
	</tr>
<?php
}
add_action( 'rcp_add_subscription_form', '\RCP\Addon\DripContent\Settings\add_subscription_form_fields' );

/**
 * Renders the schedule rows on the subscription level edit screen.
 *
 * @since 1.0
 * @param int $key The schedule row key. Used to distinguish each schedule.
 * @param array $schedule {
 *    An array of drip schedule values.
 *    @type string $type               The drip schedule type. Accepted types are "taxonomy" and "post". Required.
 *    @type string $drip_taxonomy      The taxonomy used in the schedule. Used when $type is  "taxonomy".
 *    @type string $drip_taxonomy_term The taxonomy terms used in the schedule.
 *    @type string $drip_post_type     The post type used in the schedule. Used when $type is "post".
 *    @type string $drip_post_id       The post ID used in the schedule. Used with $drip_post_type.
 *    @type int $drip_unit             The numeric unit to be used with the $drip_period below. Example: 1.
 *    @type string $drip_period        The drip period used with $drip_unit. Accepted values are "day", "month", and "year".
 * }
 */
function render_schedule_row( $key = '', array $schedule = array() ) {

	$defaults = array(
		'id'                    => 0,
		'type'                  => 'none',
		'taxonomy'              => 'none',
		'taxonomy_term'         => 'none',
		'post_type'             => 'post',
		'post_id'               => 'none',
		'unit'                  => '',
		'period'                => 'none',
		'taxonomy_type_display' => 'style="display: none;"',
		'terms_display'         => 'style="display: none;"',
		'post_type_display'     => 'style="display: none;"',
		'posts_display'         => 'style="display: none;"',
	);

	$schedule = wp_parse_args( $schedule, $defaults );

	$key = ! empty( $key ) ? absint( $key ) : 0;

	if ( ! empty( $schedule['post_id'] ) ) {
		$schedule['post_type'] = get_post_type( $schedule['post_id'] );
	}
	?>

	<tr class="rcp-drip-schedule-row">
		<td colspan="1">
			<select name="rcp-drip-settings[<?php echo $key; ?>][type]" id="rcp-drip-type-<?php echo $key; ?>" class="rcp-drip-type-control">
				<option value="none" <?php selected( $schedule['type'], 'none' ); ?>><?php _e( 'None', 'rcp-drip-content' ); ?></option>
				<option value="taxonomy" <?php selected( $schedule['type'], 'taxonomy' ); ?>><?php _e( 'Taxonomy', 'rcp-drip-content' ); ?></option>
				<option value="post" <?php selected( $schedule['type'], 'post' ); ?>><?php _e( 'Content Type', 'rcp-drip-content' ); ?></option>
			</select>
		</td>

		<td colspan="1">

			<select name="rcp-drip-settings[<?php echo $key; ?>][taxonomy]" id="rcp-drip-taxonomy-<?php echo $key; ?>" <?php echo $schedule['taxonomy_type_display']; ?> class="rcp-drip-taxonomy-control">
				<option value="none" <?php selected( $schedule['taxonomy'], 'none' ); ?>><?php _e( 'None', 'rcp-drip-content' ); ?></option>
				<?php
				foreach( get_taxonomies( array( 'public' => true, 'show_ui' => true ), 'objects' ) as $tax_key => $taxonomy ) {
					echo '<option value="' . esc_attr( $taxonomy->name ) . '" ' . selected( $schedule['taxonomy'], $taxonomy->name ) . '>' . $taxonomy->labels->name . '</option>';
				} ?>
			</select>

			<select name="rcp-drip-settings[<?php echo $key; ?>][post_type]" id="rcp-drip-post-type-<?php echo $key; ?>" <?php echo $schedule['post_type_display']; ?> class="rcp-drip-post-type-control">
				<option value="none" <?php selected( $schedule['post_type'], 'none' ); ?>><?php _e( 'None', 'rcp-drip-content' ); ?></option>
				<?php
				foreach( get_post_types( array( 'public' => true, 'show_ui' => true ), 'objects' ) as $post_type_key => $post ) {
					if ( 'attachment' === $post->name ) {
						continue;
					}
					echo '<option value="' . esc_attr( $post->name ) . '" '  . selected( $schedule['post_type'], $post->name ) .'>' . $post->labels->name . '</option>';
				}
				?>
			</select>

		</td>

		<td colspan="1">

			<select name="rcp-drip-settings[<?php echo $key; ?>][taxonomy_term]" id="rcp-drip-taxonomy-terms-<?php echo $key; ?>" <?php echo $schedule['terms_display']; ?> class="rcp-drip-taxonomy-terms-control">
				<option value="none" <?php selected( $schedule['taxonomy_term'], 'none' ); ?>><?php _e( 'None', 'rcp-drip-content' ); ?></option>
				<?php
				if ( ! empty( $schedule['taxonomy'] ) && 'none' !== $schedule['taxonomy'] ) {
					foreach( get_terms( array( 'taxonomy' => $schedule['taxonomy'], 'hide_empty' => false ) ) as $term_key => $term ) {
						echo '<option value="' . absint( $term->term_id ) . '" ' . selected( $schedule['taxonomy_term'], $term->term_id ) . '>' . $term->name . '</option>';
					}
				}
				?>
			</select>

			<select name="rcp-drip-settings[<?php echo $key; ?>][post_id]" id="rcp-drip-post-type-matches-<?php echo $key; ?>" <?php echo $schedule['posts_display']; ?> class="rcp-drip-post-type-matches-control">
				<option value="none"><?php _e( 'None', 'rcp-drip-content' ); ?></option>
				<?php
				$matches = new \WP_Query(
					array(
						'posts_per_page' => 100,
						'post_type'      => sanitize_text_field( $schedule['post_type'] ),
						'post_status'    => 'publish'
					)
				);
				foreach( $matches->posts as $post_key => $match ) {
					echo '<option value="' . absint( $match->ID ) . '" ' . selected( $schedule['post_id'], $match->ID ) . '>' . $match->post_title . '</option>';
				}
				?>
			</select>
		</td>

		<td colspan="1">
			<input type="number" name="rcp-drip-settings[<?php echo $key; ?>][unit]" id="rcp-drip-unit-<?php echo $key; ?>" value="<?php echo esc_attr( $schedule['unit'] ); ?>" style="width: 40px;" class="rcp-drip-unit-control" min="0">
		</td>

		<td colspan="1">

			<select name="rcp-drip-settings[<?php echo $key; ?>][period]" id="rcp-drip-drip-period" class="rcp-drip-unit-duration-control">
				<option value="none" <?php selected( $schedule['period'], 'none' ); ?>><?php _e( 'None', 'rcp-drip-content' ); ?></option>
				<option value="day" <?php selected( $schedule['period'], 'day' ); ?>><?php echo rcp_filter_duration_unit( 'day', 2 ); ?></option>
				<option value="month" <?php selected( $schedule['period'], 'month' ); ?>><?php echo rcp_filter_duration_unit( 'month', 2 ); ?></option>
				<option value="year" <?php selected( $schedule['period'], 'year' ); ?>><?php echo rcp_filter_duration_unit( 'year', 2 ); ?></option>
			</select>
		</td>

		<td colspan="1">
			<input name="rcp-drip-settings[<?php echo $key; ?>][schedule_id]" type="hidden" class="rcp-drip-schedule-id" value="<?php echo esc_attr( $schedule['id'] ); ?>" />
			<a href="#" class="rcp-drip-schedule-remove"><span name="rcp-drip-remove-row[[<?php echo $key; ?>]" class="dashicons dashicons-no rcp-drip-schedule-remove"></span></a>
		</td>
	</tr>

	<?php
}
add_action( 'rcp_render_drip_schedule_row', '\RCP\Addon\DripContent\Settings\render_schedule_row', 10, 2 );

/**
 * Saves the drip schedule defined on the subscription edit screen.
 */
function save_subscription_form_fields( $id, $args ) {

	if ( isset( $_GET['activate_subscription'] ) || isset( $_GET['deactivate_subscription'] ) ) {
		return;
	}

	if ( ! current_user_can( 'rcp_manage_levels' ) ) {
		return;
	}

	$existing_db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( array( 'level_id' => $id ) );

	$existing = $existing_db->schedules_for_level();

	$settings = isset( $_POST['rcp-drip-settings'] ) ? $_POST['rcp-drip-settings'] : array();

	if ( empty( $settings ) ) {
		$existing_db->delete_all_schedules_for_level(); // delete any schedules and return
		return;
	}

	$schedule_ids = array();

	foreach( $settings as $key => $setting ) {

		if ( ! empty( $setting['id'] ) ) {
			$schedule_ids[] = absint( $setting['id'] );
			$setting['id'] = absint( $setting['id'] );
		}

		if ( empty( $setting['type'] ) || 'none' === $setting['type'] ) {
			continue;
		}

		$setting['type']     = sanitize_text_field( $setting['type'] );
		$setting['level_id'] = absint( $id );

		if ( 'taxonomy' === $setting['type'] ) {
			$setting['taxonomy']      = sanitize_text_field( $setting['taxonomy'] );
			$setting['taxonomy_term'] = absint( $setting['taxonomy_term'] );
			unset( $setting['post_id'] );
		}

		if ( 'post' === $setting['type'] ) {
			$setting['post_id']   = (int) sanitize_text_field( $setting['post_id'] );
			unset( $setting['taxonomy'] );
			unset( $setting['taxonomy_term'] );
		}

		$setting['unit']   = absint( $setting['unit'] );
		$setting['period'] = in_array( $setting['period'], array( 'day', 'month', 'year' ) ) ? $setting['period'] : 'day';

		$new_db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( $setting );

		if ( $new_db->schedule_by_id() ) {
			$new_db->update_schedule();
		} else {
			$new_db->create_schedule();
		}
	}

	if ( ! empty( $existing ) ) {
		foreach( $existing as $existing_key => $existing_schedule ) {
			if ( ! in_array( $existing_schedule['id'], $schedule_ids ) ) {
				$remove_db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( array( 'id' => $existing_schedule['id'] ) );
				$remove_db->delete_schedule();
			}
		}
	}
}
add_action( 'rcp_edit_subscription_level', '\RCP\Addon\DripContent\Settings\save_subscription_form_fields', 10, 2 );
add_action( 'rcp_add_subscription', '\RCP\Addon\DripContent\Settings\save_subscription_form_fields', 10, 2 );

/**
 * Creates a list of HTML option elements for the taxonomy terms dropdown.
 */
function get_taxonomy_terms() {

	$options = '';
	$terms   = get_terms( array( 'taxonomy' => sanitize_text_field( $_POST['taxonomy'] ), 'hide_empty' => false ) );

	if ( ! is_wp_error( $terms ) ) {
		$options .= '<option value="none">' . __( 'None', 'rcp-drip-content' ) . '</option>';
		foreach( $terms as $id => $term ) {
			$options .= '<option value="' . absint( $term->term_id ) . '">' . $term->name . '</option>';
		}
	}

	return wp_send_json( array(
		'options' => $options
	) );
}
add_action( 'wp_ajax_rcp_drip_content_get_taxonomy_terms', '\RCP\Addon\DripContent\Settings\get_taxonomy_terms' );

/**
 * Creates a list of HTML option elements for the content matches dropdown.
 */
function get_posts() {

	$options = '';
	$type    = isset( $_POST['rcp-post-type'] ) ? sanitize_text_field( $_POST['rcp-post-type'] ) : 'post';
	$posts   = new \WP_Query( array(
		'post_type'      => $type,
		'posts_per_page' => 100,
		'post_status'    => 'publish'
	) );

	$options .= '<option value="none">' . __( 'None', 'rcp-drip-content' ) . '</option>';

	foreach( $posts->posts as $id => $post ) {
		$options .= '<option value="' . absint( $post->ID ) . '">' . $post->post_title . '</option>';
	}

	return wp_send_json( array(
		'options' => $options
	) );
}
add_action( 'wp_ajax_rcp_drip_content_get_posts', '\RCP\Addon\DripContent\Settings\get_posts' );

/**
 * Deletes schedules assigned to a subscription level when the level is deleted.
 *
 * @since 1.0.1
 */
function delete_schedules_for_deleted_level( $level_id ) {
	$schedule_db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( array( 'level_id' => $level_id ) );
	$schedule_db->delete_all_schedules_for_level();
}
add_action( 'rcp_remove_level', '\RCP\Addon\DripContent\Settings\delete_schedules_for_deleted_level' );