<?php

class RCPGA_Groups_Admin_Menu {

	public function __construct() {
		add_action( 'admin_menu', array( $this, 'register_menus' ), 100 );
		add_action( 'load-restrict_page_rcp-groups', array( $this, 'register_help_tabs' ) );
	}

	public function register_menus() {
		add_submenu_page( 'rcp-members','Groups', 'Groups', 'rcp_view_members', 'rcp-groups', array( $this, 'groups_admin' ) );
	}

	public function groups_admin() {

		$view = isset( $_GET['rcpga-view'] ) ? $_GET['rcpga-view'] : '';

		switch( $view ) {

			case 'edit' :
				include RCPGA_GROUPS_PLUGIN_DIR . 'includes/admin/groups/edit-group.php';
				break;

			case 'add-group' :
				include RCPGA_GROUPS_PLUGIN_DIR . 'includes/admin/groups/add-group.php';
				break;

			case 'view-members' :
				include RCPGA_GROUPS_PLUGIN_DIR . 'includes/admin/groups/members.php';
				break;

			case 'add-member' :
				include RCPGA_GROUPS_PLUGIN_DIR . 'includes/admin/groups/add-member.php';
				break;

			case 'import-members' :
				include RCPGA_GROUPS_PLUGIN_DIR . 'includes/admin/groups/import-members.php';
				break;

			default:
				if ( ! empty( $_GET['s'] ) && false !== strpos( $_GET['s'], 'member:' ) ) {
					include RCPGA_GROUPS_PLUGIN_DIR . 'includes/admin/groups/search-members.php';
				} else {
					include RCPGA_GROUPS_PLUGIN_DIR . 'includes/admin/groups/list.php';
				}
				break;

		}

	}

	/**
	 * Register help tabs on admin page.
	 *
	 * @access public
	 * @since 1.3.2
	 * @return void
	 */
	public function register_help_tabs() {

		$screen = get_current_screen();

		$screen->add_help_tab( array(
			'id'      => 'managing_groups',
			'title'   => __( 'Managing Groups', 'rcp-group-accounts' ),
			'content' => $this->render_help_tab_content( 'managing_groups' )
		) );

		$screen->add_help_tab( array(
			'id'      => 'creating_groups',
			'title'   => __( 'Creating Groups', 'rcp-group-accounts' ),
			'content' => $this->render_help_tab_content( 'creating_groups' )
		) );

		$screen->add_help_tab( array(
			'id'      => 'managing_members',
			'title'   => __( 'Managing Members', 'rcp-group-accounts' ),
			'content' => $this->render_help_tab_content( 'managing_members' )
		) );

		$screen->add_help_tab( array(
			'id'      => 'adding_members',
			'title'   => __( 'Adding Members', 'rcp-group-accounts' ),
			'content' => $this->render_help_tab_content( 'adding_members' )
		) );

		$screen->add_help_tab( array(
			'id'      => 'importing_members',
			'title'   => __( 'Importing Members', 'rcp-group-accounts' ),
			'content' => $this->render_help_tab_content( 'importing_members' )
		) );

	}

	/**
	 * Display help tab content.
	 *
	 * @param string $id ID of the tab to display content for.
	 *
	 * @access public
	 * @since 1.3.2
	 * @return string
	 */
	public function render_help_tab_content( $id ) {

		switch ( $id ) {

			case 'managing_groups' :
				ob_start();
				?>
				<p><?php _e( 'The Groups page displays an overview of all groups on your site. Hovering over a group allows you to edit it, view the members, or delete the group entirely.', 'rcp-group-accounts' ); ?></p>
				<p><?php printf( __( 'The search box allows you to search for a specific group by name. When on the group overview page, you can also search for a group member by prefixing your search with %s. This is useful if you\'re not sure which group a member is in.', 'rcp-group-accounts' ), '<code>member:</code>' ); ?></p>
				<?php
				break;

			case 'creating_groups' :
				ob_start();
				?>
				<p><?php printf( __( 'Site administrators can manually create groups through the dashboard. On the Groups page click the button to "Add Group". You can set a group name, description, and number of seats. You will also be required to choose an owner for the group. The group owner must already exist as a WordPress user and RCP member. The user can be created manually from <em>Users > Add New</em>, and the RCP membership can be manually applied from the <em>Restrict > Members</em> page. For more information, see the article on <a href="%s">how to manually add a new member</a>.' ), 'http://docs.restrictcontentpro.com/article/1705-how-to-manually-add-a-new-member' ); ?></p>
				<?php
				break;

			case 'managing_members' :
				ob_start();
				?>
				<p><?php _e( 'Clicking on the "Members" link for a group will take you to a page listing all members in that group. The table will show the display name for each member, their user ID, their role in the group, and a list of available actions. The following roles are available for group members:', 'rcp-group-accounts' ); ?></p>
				<ul>
					<li><?php _e( 'Owner - The owner of the group. This user is in charge of managing billing, renewing the membership (if applicable), and also has permission to edit group details and manage members.', 'rcp-group-accounts' ); ?></li>
					<li><?php _e( 'Admin - Group administrators do not have access to any billing details, but they do have permission to view group details and manage members.', 'rcp-group-accounts' ); ?></li>
					<li><?php _e( 'Member - Group members inherit the following information from the group owner: subscription level, membership status, and expiration date. Members do not have access to view group details or see information about other members.', 'rcp-group-accounts' ); ?></li>
					<li><?php _e( 'Invited - These are users who have been invited to join the group but have not yet accepted their invitation.', 'rcp-group-accounts' ); ?></li>
				</ul>
				<p><?php _e( 'The following actions may be available for each member:', 'rcp-group-accounts' ); ?></p>
				<ul>
					<li><?php _e( 'Remove from Group - Removes the user from the group. This does not delete the user\'s account.', 'rcp-group-accounts' ); ?></li>
					<li><?php _e( 'Set as Member - This link appears for any member who does not have the role "member", such as admins and invited users who have not yet accepted their invitation. Clicking the link will change the member\'s role to "member".', 'rcp-group-accounts' ); ?></li>
					<li><?php _e( 'Set as Admin - This link is visible for users with the role "member". Clicking it will promote the member to the admin role, which gives the user permission to view group details and manage members.', 'rcp-group-accounts' ); ?></li>
					<li><?php _e( 'Set as Owner - Clicking this link will promote the member to "owner" rank. Only one owner can exist for each group, so the existing owner will be demoted to "admin" rank. Group owners are responsible for managing the billing/membership for the group.', 'rcp-group-accounts' ); ?></li>
					<li><?php _e( 'Resend  Invite - This link appears for users with the "invited" role. Clicking the link will resend the invitation email to the user.', 'rcp-group-accounts' ); ?></li>
				</ul>
				<?php
				break;

			case 'adding_members' :
				ob_start();
				?>
				<p><?php _e( 'Members can be manually added to a group by a site administrator. Locate the group you want to add the member to and click the "Members" link. On the new page, click the "Add Member" button at the top. You will be required to enter an email address for the member and specify whether or not the user already has an account. If not, check the "new member" box to create a new account for the member. The new member will be sent an invitation email.', 'rcp-group-accounts' ); ?></p>
				<?php
				break;

			case 'importing_members' :
				ob_start();
				?>
				<p><?php printf( __( 'Members can be imported to a group from a CSV file. Locate the group in the table and click the "Members" link. On the group members page, click the button at the top labeled "Import Members". Upload your CSV file and click the import button. Be sure to follow the required formatting in the <a href="%s">sample CSV file</a>.', 'rcp-group-accounts' ), esc_url( RCPGA_GROUPS_PLUGIN_URL . 'member-import-sample.csv' ) ); ?></p>
				<?php
				break;

		}

		return ob_get_clean();

	}

}
$rcp_groups_admin_menu = new RCPGA_Groups_Admin_Menu;