<?php
/**
 * Filters
 *
 * @package     RCP\IP_Restriction\Filters
 * @since       1.0.0
 */


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Add error on registration form for blacklisted IPs
 *
 * @since       1.0.0
 * @param       object $post The WordPress post object
 * @return      void
 */
function rcp_ip_restriction_registration_blacklist( $post ) {
	if ( rcp_ip_restriction_is_blacklisted() ) {
		$settings = get_option( 'rcp_ip_restriction_settings' );

		if ( isset( $settings['blacklist_error'] ) ) {
			$blacklist_error = $settings['blacklist_error'];
		} else {
			$blacklist_error = __( 'An unknown error has occurred, please try again.', 'rcp-ip-restriction' );
		}

		if ( rcp_ip_restriction()->debugging ) {
			s214_debug_log_error( 'Blacklist Notice', 'Blacklisted IP ' . rcp_get_ip() . ' attempted to subscribe.', 'RCP IP Restriction' );
		}

		rcp_errors()->add( 'ip_error', $blacklist_error, 'register' );
	}
}
add_action( 'rcp_before_form_errors', 'rcp_ip_restriction_registration_blacklist' );

/**
 * Delete a subscription level's IP whitelist when the level is deleted.
 *
 * @param int $subscription_level_id ID of the subscription level being deleted.
 *
 * @since 1.2.4
 * @return void
 */
function rcp_ip_restriction_clear_level_whitelist( $subscription_level_id ) {

	$subscription_whitelists = get_option( 'rcp_ip_restriction_subscription_whitelists' );

	if ( ! is_array( $subscription_whitelists ) ) {
		return;
	}

	if ( ! array_key_exists( $subscription_level_id, $subscription_whitelists ) ) {
		return;
	}

	if ( function_exists( 'rcp_log' ) ) {
		rcp_log( sprintf( 'Deleting IP whitelist for subscription level #%d.', $subscription_level_id ) );
	}

	unset( $subscription_whitelists[ $subscription_level_id ] );

	update_option( 'rcp_ip_restriction_subscription_whitelists', $subscription_whitelists );

}
add_action( 'rcp_remove_level', 'rcp_ip_restriction_clear_level_whitelist' );