<?php
/**
 * Filters
 *
 * @package     RCP\IP_Restriction\Filters
 * @since       1.0.0
 */


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Override RCP can_access
 *
 * @since       1.0.0
 * @param       bool $can_access The current access condition
 * @param       int $user_id The ID of the current user
 * @param       int $post_id The ID of the current post
 * @param       object $member The RCP Member object
 * @return      bool $can_access True if whitelisted, false otherwise
 */
function rcp_ip_restriction_member_can_access( $can_access, $user_id = 0, $post_id = 0, $member = false ) {
	if ( ! $can_access ) {
		// Check whitelist
		if ( rcp_ip_restriction_is_whitelisted( $post_id ) ) {
			$can_access = true;
		}
	}

	return $can_access;
}
add_filter( 'rcp_member_can_access', 'rcp_ip_restriction_member_can_access', 10, 4 );


/**
 * Override restrict shortcode
 *
 * @since       1.0.1
 * @param       bool $has_access The current access condition
 * @param       int $user_id The ID of the current user
 * @param       array $atts Arguements passed to the shortcode
 * @return      bool $has_access True if whitelisted, false otherwise
 */
function rcp_ip_restriction_shortcode_can_access( $has_access, $user_id = 0, $atts ) {
	if ( ! $has_access ) {
		// Check whitelist
		if ( rcp_ip_restriction_is_whitelisted( get_the_ID() ) ) {
			$has_access = true;
		}
	}

	return $has_access;
}
add_filter( 'rcp_restrict_shortcode_has_access', 'rcp_ip_restriction_shortcode_can_access', 10, 3 );
