<?php

namespace RCP\Addon\RestrictPastContent;

defined( 'WPINC' ) or die;

/**
 * Determines if the member can access the requested content
 * based on the member's join date.
 * @since 1.0
 * @return bool True if the content is visible to the member, false if not.
 */
function can_access( $ret, $user_id, $post_id, $user ) {

	if ( ! $ret ) {
		return false;
	}

	if ( ! rcp_is_restricted_content( $post_id ) ) {
		return $ret;
	}

	if ( ! is_user_logged_in() ) {
		return $ret;
	}

	// Return early for editors to avoid additional queries.
	if ( user_can( $user, 'edit_others_posts' ) ) {
		return true;
	}

	$sub_id = (int) rcp_get_subscription_id( $user_id );

	if ( ! $sub_id ) {
		return $ret;
	}

	global $rcp_levels_db;

	if ( ! $rcp_levels_db->get_meta( $sub_id, 'restrict_past_content', true ) ) {
		return $ret;
	}

	$member = new \RCP_Member( wp_get_current_user()->ID );

	$timezone = get_option( 'timezone_string' );

	$timezone = ! empty( $timezone ) ? $timezone : 'UTC';

	$join_date = new \DateTime( $member->get_joined_date( $sub_id ), new \DateTimeZone( $timezone ) );

	$join_date->modify( 'midnight' );

	$post_date = new \DateTime( get_post_field( 'post_date', $post_id ), new \DateTimeZone( $timezone ) );

	$offset = $rcp_levels_db->get_meta( $sub_id, 'restrict_past_content_offset', true );

	if ( $offset ) {
		$offset =- $offset . ' days';
		$join_date->modify( $offset );
	}

	if ( $post_date >= $join_date ) {
		$ret = true;
	} else {
		$ret = false;
	}

	$exclude = get_post_meta( $post_id, 'rcp_restrict_past_content_exclude', true );

	if ( ! $ret && ! empty( $exclude ) ) {
		$ret = true;
	}

	return $ret;
}