<?php
/**
 * Cron functions
 *
 * @package     RCP\Restriction_Timeouts\Cron
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Setup our cron job
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_restriction_timeouts_setup_cron() {
	if( ! wp_next_scheduled( 'rcp_restriction_timeouts_expire' ) ) {
		wp_schedule_event( current_time( 'timestamp' ), 'daily', 'rcp_restriction_timeouts_expire' );
	}
}
add_action( 'wp', 'rcp_restriction_timeouts_setup_cron' );


/**
 * Run the expiration cron
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_restriction_timeouts_expire() {

	$current_time = current_time( 'timestamp' );

	// Posts
	$posts = get_posts( array(
		'post_type'      => get_post_types(),
		'posts_per_page' => 100,
		'post_status'    => 'publish',
		'meta_query'     => array(
			array(
				'key'    => 'rcp_timeout'
			)
		)
	) );

	$fields = array(
		'_is_paid',
		'rcp_hide_from_feed',
		'rcp_subscription_level',
		'rcp_timeout'
	);

	foreach( $posts as $post ) {
		$expire_time = get_post_meta( $post->ID, 'rcp_timeout', true );

		if( $current_time >= strtotime( $expire_time, $current_time ) ) {
			foreach( $fields as $field ) {
				delete_post_meta( $post->ID, $field );
			}
		}

		update_post_meta( $post->ID, 'rcp_timeout_was', $expire_time );

	}

	// Taxonomy terms
	$terms = get_terms( array(
		'meta_query' => array(
			array(
				'key' => 'rcp_timeout'
			)
		)
	) );

	foreach( $terms as $term ) {
		$expire_time = rcp_restriction_timeouts_get_term_timeout( $term->term_id );

		if( $current_time >= strtotime( $expire_time, $current_time ) ) {
			if ( ( ! function_exists( 'delete_term_meta' ) ) || ! delete_term_meta( $term->term_id, 'rcp_timeout' ) ) {
				delete_option( "rcp_timeout_$term->term_id" );
			}

			if( function_exists( 'update_term_meta' ) ) {

				update_term_meta( $term->term_id, 'rcp_timeout_was', $expire_time );

			}
		}
	}
}
add_action( 'rcp_restriction_timeouts_expire', 'rcp_restriction_timeouts_expire' );
