<?php
/**
 * Helper functions
 *
 * @package     RCP\Restriction_Timeouts\Functions
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Get timeout for the provided term_id
 *
 * @since       1.0.0
 * @param       int $term_id The ID of this term
 * @return      mixed|void
 */
function rcp_restriction_timeouts_get_term_timeout( $term_id ) {
	// Fallback to older method of handling term meta if term meta does not exist
	if( ( ! function_exists( 'get_term_meta' ) ) || ! $timeout = get_term_meta( $term_id, 'rcp_timeout', true ) ) {
		$timeout = get_option( "rcp_timeout_$term_id" );
	}

	return apply_filters( 'rcp_restriction_timeouts_get_term_timeout', $timeout, $term_id );
}

/**
 * Get past timeout for the provided term_id
 *
 * @since       1.0.0
 * @param       int $term_id The ID of this term
 * @return      string
 */
function rcp_restriction_timeouts_get_past_term_timeout( $term_id ) {
	
	$timeout_was = '';

	if( function_exists( 'get_term_meta' ) ) {

		$timeout_was = get_term_meta( $term_id, 'rcp_timeout_was', true );

	}

	return $timeout_was;
}

/**
 * Check timeout when post is accessed
 *
 * @since       1.0.0
 * @param       bool   $can_access Can member access post?
 * @param       int    $user_id The ID of the user
 * @param       int    $post_id The ID of the post
 * @param       object $member The RCP_Member object
 * @return      bool
 */
function rcp_restriction_timeouts_can_access( $can_access, $user_id, $post_id, $member ) {

	if( ! $can_access ) {

		$expire_time = get_post_meta( $post_id, 'rcp_timeout', true );
		$timenow     = current_time( 'timestamp' );

		if( $expire_time && $timenow > strtotime( $expire_time, $current_time ) ) {

			// Timeout has passed, remove the restriction

			$fields = array(
				'_is_paid',
				'rcp_hide_from_feed',
				'rcp_subscription_level',
				'rcp_timeout'
			);

			foreach( $fields as $field ) {
				delete_post_meta( $post_id, $field );
			}

			update_post_meta( $post_id, 'rcp_timeout_was', $expire_time );

			remove_filter( 'rcp_member_can_access', 'rcp_restriction_timeouts_can_access', 1 );

			// Check access again
			$can_access = $member->can_access( $post_id );

			add_filter( 'rcp_member_can_access', 'rcp_restriction_timeouts_can_access', 1, 4 );

		}
	}

	return $can_access;
}
add_filter( 'rcp_member_can_access', 'rcp_restriction_timeouts_can_access', 1, 4 );