<?php
/**
 * Filters
 *
 * @package     RCP\Site_Creation\Filters
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Add the subsite field to the registration form
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_site_creation_registration_fields() {
	ob_start();

    if( ! is_user_logged_in() || ! rcp_site_creation_get_user_blog( get_current_user_id() ) ) {
		$settings = get_option( 'rcp_site_creation_settings' );
		$schemes  = ( ! empty( $settings['domain_mapping_schemes'] ) && is_array( $settings['domain_mapping_schemes'] ) ) ? $settings['domain_mapping_schemes'] : array( 'http' );
?>
		<div id="rcp_site_creation_fields_wrap">
			<p id="rcp_site_creation_url_wrap">
				<label for="rcp_site_creation_url"><?php echo ( isset( $settings['url_field_title'] ) && ! empty( $settings['url_field_title'] ) ? $settings['url_field_title'] : __( 'Subsite URL', 'rcp-site-creation' ) ); ?></label>
				<?php if ( ! empty( $settings['domain_mapping'] ) ) :
					if ( count( $schemes ) > 1 ) : ?>
					<select id="rcp_site_creation_url_scheme" name="rcp_site_creation_url_scheme">
						<option value="https"><?php _e( 'https://', 'rcp-site-creation' ); ?></option>
						<option value="http"><?php _e( 'http://', 'rcp-site-creation' ); ?></option>
					</select>
					<?php else : ?>
						<span id="rcp_site_creation_url_prefix"><?php echo $schemes[0] . '://'; ?></span>
						<input type="hidden" id="rcp_site_creation_url_scheme" name="rcp_site_creation_url_scheme" value="<?php echo esc_attr( $schemes[0] ); ?>">
					<?php endif; ?>
				<?php endif; ?>
				<input id="rcp_site_creation_url" name="rcp_site_creation_url" type="text" value="<?php echo ( isset( $_POST['rcp_site_creation_url'] ) ? $_POST['rcp_site_creation_url'] : '' ); ?>" /><br />
				<span class="rcp_site_creation_url_preview_wrap" style="display: none"><span class="rcp_site_creation_url_preview_label"><?php _e( 'Preview:', 'rcp-site-creation' ); ?></span>&nbsp;<code><span class="rcp_site_creation_url_preview_subdomain"></span></code></span>
			</p>

			<p id="rcp_site_creation_name_wrap">
				<label for="rcp_site_creation_name"><?php echo ( isset( $settings['name_field_title'] ) && ! empty( $settings['name_field_title'] ) ? $settings['name_field_title'] : __( 'Subsite Name', 'rcp-site-creation' ) ); ?></label>
				<input id="rcp_site_creation_name" name="rcp_site_creation_name" type="text" value="<?php echo ( isset( $_POST['rcp_site_creation_name'] ) ? $_POST['rcp_site_creation_name'] : '' ); ?>" />
			</p>

			<?php if( ! empty( $settings['desc_field_show'] ) ) : ?>
				<p id="rcp_site_creation_desc_wrap">
					<label for="rcp_site_creation_desc"><?php echo ( isset( $settings['desc_field_title'] ) && ! empty( $settings['desc_field_title'] ) ? $settings['desc_field_title'] : __( 'Subsite Description', 'rcp-site-creation' ) ); ?></label>
					<input id="rcp_site_creation_desc" name="rcp_site_creation_desc" type="text" value="<?php echo ( isset( $_POST['rcp_site_creation_desc'] ) ? $_POST['rcp_site_creation_desc'] : '' ); ?>" />
				</p>
			<?php endif; ?>

			<?php
			/**
			 * Fires immediately after the site creation registration fields are rendered.
			 *
			 * @since 1.2
			 *
			 * @param array $settings RCP Site Creation settings.
			 */
			do_action( 'rcp_site_creation_registration_fields', $settings ); ?>
		</div>
<?php
	}

	echo ob_get_clean();
}
add_action( 'rcp_after_register_form_fields', 'rcp_site_creation_registration_fields', 100 );


/**
 * Add error on registration form for unavailable URLs
 *
 * @since       1.0.0
 * @param       object $post The WordPress post object
 * @return      void
 */
function rcp_site_creation_registration_errors( $post ) {
	if( ! is_user_logged_in() || ! rcp_site_creation_get_user_blog( get_current_user_id() ) ) {

		// Double check if the selected level is allowed to create sites
		if( isset( $_POST['rcp_level'] ) ) {
			if( ! rcp_site_creation_allowed( $_POST['rcp_level'] ) && isset( $_POST['rcp_site_creation_url'] ) && $_POST['rcp_site_creation_url'] !== '' ) {
				$_POST['rcp_site_creation_url'] = '';
			} elseif( rcp_site_creation_allowed( $_POST['rcp_level'] ) ) {
				$settings = get_option( 'rcp_site_creation_settings' );

				// URL is required!
				if( ! isset( $_POST['rcp_site_creation_url'] ) || $_POST['rcp_site_creation_url'] == '' || ! isset( $_POST['rcp_site_creation_name'] ) || $_POST['rcp_site_creation_name'] == '' ) {
					if( ! isset( $_POST['rcp_site_creation_url'] ) || $_POST['rcp_site_creation_url'] == '' ) {
						if( isset( $settings['subsite_required_error'] ) ) {
							$subsite_required_error = $settings['subsite_required_error'];
						} else {
							$subsite_required_error = __( 'The subsite URL field is required, please try again.', 'rcp-site-creation' );
						}

						rcp_errors()->add( 'subsite_required_error', $subsite_required_error, 'register' );
					}

					if( ! isset( $_POST['rcp_site_creation_name'] ) || $_POST['rcp_site_creation_name'] == '' ) {
						if( isset( $settings['name_required_error'] ) ) {
							$name_required_error = $settings['name_required_error'];
						} else {
							$name_required_error = __( 'The subsite name field is required, please try again.', 'rcp-site-creation' );
						}

						rcp_errors()->add( 'name_required_error', $name_required_error, 'register' );
					}
				} else {
					// Make sure the URL is available
					$subsite = rcp_site_creation_sanitize_url( $_POST['rcp_site_creation_url'] );

					if( rcp_site_creation_get_id_from_blogname( $subsite ) || ( ! is_subdomain_install() && isset( $settings['safe_urls'] ) && get_page_by_path( $subsite ) ) ) {
						if( isset( $settings['subsite_exists_error'] ) ) {
							$subsite_exists_error = $settings['subsite_exists_error'];
						} else {
							$subsite_exists_error = __( 'The specified subsite URL is not available, please try again.', 'rcp-site-creation' );
						}

						rcp_errors()->add( 'subsite_exists_error', $subsite_exists_error, 'register' );
					}
				}
			}

			/**
			 * Fires immediately after core errors have been collected for registration fields.
			 *
			 * @since 1.2
			 *
			 * @param \WP_Post $post     Post object.
			 * @param array    $settings RCP Site Creation settings array.
			 */
			do_action( 'rcp_site_creation_registration_errors', $post, $settings );
		}
	}
}
add_action( 'rcp_before_form_errors', 'rcp_site_creation_registration_errors' );

/**
 * Set pending user meta during registration so we know to create the site later
 *
 * @param array $post    Posted data.
 * @param int   $user_id ID of the user who's registering.
 * @param float $price   Price of the subscription.
 *
 * @since 1.1.4
 */
function rcp_site_creation_create_pending_site( $post, $user_id, $price ) {

	if( isset( $post['rcp_level'] ) && rcp_site_creation_allowed( $post['rcp_level'] ) && isset( $post['rcp_site_creation_url'] ) && $post['rcp_site_creation_url'] !== '' ) {
		$site_args = array(
			'name'        => sanitize_text_field( $post['rcp_site_creation_name'] ),
			'description' => isset( $post['rcp_site_creation_desc'] ) ? sanitize_text_field( $post['rcp_site_creation_desc'] ) : '',
			'url'         => sanitize_text_field( $_POST['rcp_site_creation_url'] ),
			'scheme'      => isset( $_POST['rcp_site_creation_url_scheme'] ) ? sanitize_text_field( $_POST['rcp_site_creation_url_scheme'] ) : 'http'
		);

		update_user_meta( absint( $user_id ), 'rcp_site_creation_pending_site', $site_args );

		/**
		 * Fires immediately after a pending site has been created.
		 *
		 * @since 1.2
		 *
		 * @param \WP_Post $post      Post object.
		 * @param int      $user_id   User ID.
		 * @param array    $site_args Arguments set for the new pending site.
		 */
		do_action( 'rcp_site_creation_create_pending_site', $post, $user_id, $site_args );
	}

}
add_action( 'rcp_form_processing', 'rcp_site_creation_create_pending_site', 10, 3 );


/**
 * Create subsite when membership is activated
 *
 * @param string $status     New status being set.
 * @param int    $user_id    ID of the user.
 * @param string $old_status Previous status before the update.
 * @param RCP_Member $member Member object.
 *
 * @since  1.0.0
 * @return void
 */
function rcp_site_creation_set_status( $status, $user_id, $old_status, $member ) {
	if( ! in_array( $status, array( 'active', 'free' ) ) ) {
		return;
	}

	$site_meta = get_user_meta( $user_id, 'rcp_site_creation_pending_site', true );

	if ( empty( $site_meta ) || ! is_array( $site_meta ) || empty( $site_meta['url'] ) ) {
		return;
	}

	$site_name  = sanitize_text_field( $site_meta['name'] );
	$new_domain = rcp_site_creation_get_format( $site_meta['url'] );
	$scheme     = $site_meta['scheme'];
	$quota      = rcp_site_creation_get_upload_quota( $member->get_subscription_id() );
	$settings   = get_option( 'rcp_site_creation_settings' );
	$status     = apply_filters( 'rcp_site_creation_status', array( 'public' => 1 ) );

	$meta = $status;

	if( ! empty( $site_meta['description'] ) ) {
		$meta += array( 'blogdescription' => sanitize_text_field( $site_meta['description'] ) );
	}

	if ( ! empty( $quota ) ) {
		$meta += array( 'blog_upload_space' => absint( $quota ) );
	}

	if ( ! empty( $settings['domain_mapping'] ) ) {
		// We need to overwrite the site/home URLs manually in order to change the scheme.
		$url = $scheme . '://' . $new_domain['domain'];
		$meta += array(
			'siteurl' => sanitize_text_field( $url ),
			'home'    => sanitize_text_field( $url )
		);
	}

	$meta = apply_filters( 'rcp_site_creation_meta', $meta );

	$blog_id = wpmu_create_blog( $new_domain['domain'], $new_domain['path'], $site_name, $user_id, $meta );

	// Set theme.
	if ( isset( $settings['default_theme'] ) && ! empty( $settings['default_theme'] ) ) {
		switch_to_blog( $blog_id );
		switch_theme( $settings['default_theme'] );
		restore_current_blog();
	}

	/**
	 * Fires immediately after a site has been created and the default theme set,
	 * but before the user meta flag is deleted.
	 *
	 * @since 1.2
	 *
	 * @param array $site_meta Array of meta for the newly-added site.
	 * @param int   $blog_id   ID of the new site.
	 * @param int   $user_id   User ID for the admin associated with the new site.
	 */
	do_action( 'rcp_site_creation_site_created', $site_meta, $blog_id, $user_id );

	update_user_meta( $user_id, 'rcp_site_creation_blog_id', $blog_id );
	delete_user_meta( $user_id, 'rcp_site_creation_pending_site' );
}
add_action( 'rcp_set_status', 'rcp_site_creation_set_status', 10, 4 );

/**
 * Update an existing subsite when the member's status is updated
 *
 * @param string $status     New status being set.
 * @param int    $user_id    ID of the user.
 * @param string $old_status Previous status before the update.
 * @param RCP_Member $member Member object.
 *
 * @since 1.1.4
 * @return void
 */
function rcp_site_creation_update_blog( $status, $user_id, $old_status, $member ) {

	$blog_id = rcp_site_creation_get_user_blog( $user_id );

	if ( empty( $blog_id ) ) {
		return;
	}

	if( $status == 'expired' ) {

		// Delete blog when subscription expires.
		do_action( 'deactivate_blog', $blog_id );
		update_blog_status( $blog_id, 'deleted', '1' );

	} elseif( $status == 'active' ) {

		// Re-activate blog when subscription is re-activated.
		update_blog_status( $blog_id, 'deleted', '0' );
		do_action( 'activate_blog', $blog_id );

		// Update quota on subscription upgrade.
		$member = new RCP_Member( $user_id );

		// Change upload space allowance on upgrade.
		if ( $member->just_upgraded() ) {
			$quota = rcp_site_creation_get_upload_quota( $member->get_subscription_id() );

			if ( ! empty( $quota ) ) {
				update_blog_option( $blog_id, 'blog_upload_space', absint( $quota ) );
			}
		}

	}

}
add_action( 'rcp_set_status', 'rcp_site_creation_update_blog', 10, 4 );