<?php
/**
 * Edit Member Page
 *
 * @package   RCP\RCP_Site_Creation\Admin\Edit Member
 * @copyright Copyright (c) 2017, Restrict Content Pro
 * @license   GPL2+
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Display site information on the Edit Member page
 *
 * @param int $user_id ID of the member being edited.
 *
 * @since 1.1.4
 * @return void
 */
function rcp_site_creation_edit_member( $user_id ) {

	$blog_id = rcp_site_creation_get_user_blog( $user_id );
	?>
	<tr valign="top">
		<th scope="row" valign="top">
			<label for="rcp-site-creation-blog"><?php _e( 'Site', 'rcp-site-creation' ); ?></label>
		</th>
		<td>
			<?php if ( ! empty( $blog_id ) ) :
				$details = get_blog_details( $blog_id );
				?>
				<a href="<?php echo esc_url( $details->home ); ?>" target="_blank" title="<?php esc_attr_e( 'Visit site', 'rcp-site-creation' ); ?>"><?php echo esc_html( $details->blogname ); ?></a> |
				<a href="<?php echo esc_url( get_admin_url( $blog_id ) ); ?>" target="_blank"><?php _e( 'Dashboard', 'rcp-site-creation' ); ?></a> |
				<a href="<?php echo esc_url( network_admin_url( 'site-info.php?id=' . $details->blog_id ) ); ?>" target="_blank"><?php _e( 'Edit', 'rcp-site-creation' ); ?></a>
			<?php else : ?>
				<input type="number" id="rcp-site-creation-blog" name="rcp_site_creation_blog" value=""/>
				<p class="description"><?php _e( 'Enter a site ID number to associate it with this member.', 'rcp-site-creation' ); ?></p>
			<?php endif; ?>
		</td>
	</tr>
	<?php

}

add_action( 'rcp_edit_member_after', 'rcp_site_creation_edit_member' );

/**
 * Associate a member with an existing site
 *
 * @param int $user_id ID of the member being edited.
 *
 * @since 1.1.4
 * @return void
 */
function rcp_site_creation_add_blog_to_member( $user_id ) {

	if ( ! isset( $_POST['rcp_site_creation_blog'] ) ) {
		return;
	}

	if ( ! current_user_can( 'rcp_manage_members' ) ) {
		wp_die( __( 'You do not have permission to perform this action.', 'rcp-site-creation' ), __( 'Error', 'rcp-site-creation' ), array( 'response' => 403 ) );
	}

	$blog_id = absint( $_POST['rcp_site_creation_blog'] );

	if ( empty( $blog_id ) ) {
		return;
	}

	// Make sure this blog ID isn't already associated with a member.
	$members = get_users( array(
		'meta_key'   => 'rcp_site_creation_blog_id',
		'meta_value' => $blog_id,
		'fields'     => 'ids'
	) );

	if ( ! empty( $members ) ) {
		wp_die( sprintf( __( 'Blog #%d is already associated with user #%d. A blog can only be associated with one member.', 'rcp-site-creation' ), $blog_id, reset( $members ) ), __( 'Error', 'rcp-site-creation' ), array( 'response' => 400 ) );
	}

	update_user_meta( $user_id, 'rcp_site_creation_blog_id', $blog_id );

}

add_action( 'rcp_edit_member', 'rcp_site_creation_add_blog_to_member' );