<?php
/**
 * Cron functions
 *
 * @package     RCP\Timelock\Cron
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Setup our cron job
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_timelock_setup_cron() {
	if( ! wp_next_scheduled( 'rcp_timelock_restrict' ) ) {
		wp_schedule_event( current_time( 'timestamp' ), 'daily', 'rcp_timelock_restrict' );
	}
}
add_action( 'wp', 'rcp_timelock_setup_cron' );


/**
 * Run the restriction cron
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_timelock_restrict() {
	$current_time = current_time( 'm/d/Y H:i' );

	// Posts
	$posts = get_posts( array(
		'post_type'   => get_post_types(),
		'post_status' => 'publish',
		'meta_query'  => array(
			array(
				'key' => 'rcp_timelock'
			)
		)
	) );

	$fields = array(
		'rcp_timelock'
	);

	foreach( $posts as $post ) {
		$restrict_time = get_post_meta( $post->ID, 'rcp_timelock', true );

		if( strtotime( $current_time ) >= strtotime( esc_attr( $restrict_time ) ) ) {
			foreach( $fields as $field ) {
				delete_post_meta( $post->ID, $field );
			}
		}
	}
}
add_action( 'rcp_timelock_restrict', 'rcp_timelock_restrict' );
